@@ -2,7 +2,7 @@ package Algorithm::Evolutionary;
 
 use Carp qw(croak);
 
-our $VERSION = '0.78_2'; # Another year in paradise
+our $VERSION = '0.79_1'; # Getting close to something
 
 # Preloaded methods go here.
 
@@ -32,6 +32,8 @@ sub import {
 1;
 __END__
 
+=encoding utf8
+
 =head1 NAME
 
 Algorithm::Evolutionary - Perl module for performing paradigm-free evolutionary algorithms. 
@@ -53,7 +55,7 @@ evolutionary computation in Perl. Why would anyone want to do that
 escapes my knowledge, but, in fact, we have found it quite useful for
 our own purposes. Same as Perl itself.
 
-The design principle of L<Algorithm::Evolutionary> is I<flexibility>: it
+The main design principle of L<Algorithm::Evolutionary> is I<flexibility>: it
 should be very easy to create your own evolutionary algorithms using this library, and it should be
 also quite easy to program what's already there in the evolutionary
 computation community. Besides, the library classes should have
@@ -65,26 +67,18 @@ web.
 
 =begin html
 
-<p>The project is hosted at
-<a href='http://opeal.sourceforge.net'>Sourceforge</a>. Latest aditions, and
+<p>The project has been, from version 0.79, moved to
+<a href='http://github.com/JJ/Algorithm-Evolutionary'>GitHub</a>. Latest aditions, and
 nightly updates, can be downloaded from there before they are uploaded
 to CPAN. That page also hosts the mailing list, as well as bug
 reports, news, updates, work in progress, lots of stuff.</p>
 
 <p>In case the examples are hidden somewhere in the <code>.cpan</code> directory,
     you can also download them from <a
-    href='http://opeal.cvs.sourceforge.net/opeal/Algorithm-Evolutionary/'>the
-    CVS repository</a>, and the <a
-    href='https://sourceforge.net/project/showfiles.php?group_id=34080&package_id=54504'>-examples</a>
-    tarballs in the file download area of that repository</p>
-
-<p>You can also get help from the <a
-href='https://sourceforge.net/projects/opeal/forums/forum/107255'>project
-forum</a> (where I usually hang around) or from <a
-href='mailto:opeal-help-request@lists.sourceforge.net'>the mailing
-list</a> (information at <a
-href='https://lists.sourceforge.net/lists/listinfo/opeal-help'>its web
-site</a>).</p> 
+    href='https://github.com/JJ/Algorithm-Evolutionary/tree/master/examples'>the
+    git repository</a>. You can also get help from the <a
+href='https://github.com/JJ/Algorithm-Evolutionary/issues'>project
+issues</a>.</p> 
 
 <p>It might be also helpful for you to check out <a
 href='http://arxiv.org/abs/0908.0516'>Still doing evolutionary
@@ -101,8 +95,8 @@ research, I would be very grateful if you quoted papers such as these
 =end html
 
  @article {springerlink:10.1007/s00500-009-0504-3,
-   author = {Merelo Guervs, Juan-Julin and Castillo, Pedro and Alba, Enrique},
-   affiliation = {Universidad de Granada Depto. Arquitectura y Tecnologa de Computadores, ETS Ingenieras Informtica y Telecomunicaciones Granada Spain},
+   author = {Merelo Guervós, Juan-Julián and Castillo, Pedro and Alba, Enrique},
+   affiliation = {Universidad de Granada Depto. Arquitectura y Tecnología de Computadores, ETS Ingenierías Informática y Telecomunicaciones Granada Spain},
    title = {Algorithm::Evolutionary, a flexible Perl module for evolutionary computation},
    journal = {Soft Computing - A Fusion of Foundations, Methodologies and Applications},
    publisher = {Springer Berlin / Heidelberg},
@@ -119,7 +113,7 @@ research, I would be very grateful if you quoted papers such as these
  @InProceedings{jj:2008:PPSN,
    author =	"Juan J. Merelo and  Antonio M. Mora and Pedro A. Castillo
                  and Juan L. J. Laredo and Lourdes Araujo and Ken C. Sharman
-                 and Anna I. Esparcia-Alczar and Eva Alfaro-Cid
+                 and Anna I. Esparcia-Alcázar and Eva Alfaro-Cid
                  and Carlos Cotta",
    title =	"Testing the Intermediate Disturbance Hypothesis: Effect of
                  Asynchronous Population Incorporation on Multi-Deme
@@ -192,12 +186,12 @@ Main author and developer is J. J. Merelo, jmerelo (at) geneura.ugr.es
 who blogs at <a href='http://blojj.blogalia.com'>BloJJ</a> and
 twitters at <a
 href='http://twitter.com/jjmerelo'>twitter.com/jjmerelo</a>. There have
-also been some contributions from Javi Garca, fjgc (at) decsai.ugr.es
+also been some contributions from Javi García, fjgc (at) decsai.ugr.es
 and Pedro Castillo, pedro (at) geneura.ugr.es. 
 
 Patient users that have submitted bugs include <a
 href='http://barbacana.net'>jamarier</a>, <a
-href='http://leandrohermida.com'>Leandro Hermida</a>, Jrme Qulin
+href='http://leandrohermida.com'>Leandro Hermida</a>, Jérôme Quélin,
 Mike Gajewski and Cristoph Meissner. <a href='http://alexm.org'>Alex
 Muntada</a>, from the <a href='http://barcelona.pm.org/'>Barcelona
 Perl Mongers</a>, helped me solve a problem with the Makefile.PL.
@@ -250,9 +244,4 @@ L<AI::Genetic::Pro>.
 This file is released under the GPL. See the LICENSE file included in this distribution,
 or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2012/07/09 15:46:15 $ 
-  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary.pm,v 3.22 2012/07/09 15:46:15 jmerelo Exp $ 
-  $Author: jmerelo $ 
-  $Revision: 3.22 $
-
 =cut
