@@ -1,9 +1,11 @@
-use strict;
+use strict; #-*-cperl-*-
 use warnings;
 
+use lib qw( ../../../../lib );
+
 =head1 NAME
 
-    Algorithm::Evolutionary::Fitness::Base - Base class for Fitness functions
+Algorithm::Evolutionary::Fitness::Base - Base class for Fitness functions
 
 =head1 SYNOPSIS
 
@@ -12,8 +14,8 @@ used to implement fitness functions
 
 =head1 DESCRIPTION
 
-Has functionality that should be common to all fitness. Or at least it
-would be nice to have it in common
+This module includes functionality that should be common to all fitness. Or at least it
+would be nice to have it in common.
 
 =head1 METHODS
 
@@ -23,7 +25,7 @@ package Algorithm::Evolutionary::Fitness::Base;
 
 use Carp;
 
-our ($VERSION) = ( '$Revision: 2.1 $ ' =~ /(\d+\.\d+)/ );
+our ($VERSION) = ( '$Revision: 3.1 $ ' =~ / (\d+\.\d+)/ );
 
 
 =head2 new()
@@ -49,7 +51,7 @@ Called from new, initializes the evaluations counter.
 sub initialize {
   my $self = shift;
   $self->{_counter} = 0; 
-  $self->{_cache} = {};
+  $self->{_cache} = {}; # This is optional; should be used from derived classes
 }
 
 
@@ -141,6 +143,10 @@ L<Algorithm::Evolutionary::Fitness::ECC>
 
 L<Algorithm::Evolutionary::Fitness::Royal_Road>
 
+=item * 
+
+L<Algorithm::Evolutionary::Fitness::String>
+
 =back
 
 =head1 Copyright
@@ -148,10 +154,10 @@ L<Algorithm::Evolutionary::Fitness::Royal_Road>
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2009/02/04 20:43:14 $ 
-  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Fitness/Base.pm,v 2.1 2009/02/04 20:43:14 jmerelo Exp $ 
+  CVS Info: $Date: 2010/09/24 08:39:07 $ 
+  $Header: /media/Backup/Repos/opeal/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Fitness/Base.pm,v 3.1 2010/09/24 08:39:07 jmerelo Exp $ 
   $Author: jmerelo $ 
-  $Revision: 2.1 $
+  $Revision: 3.1 $
   $Name $
 
 =cut
