@@ -1,4 +1,4 @@
-use strict; #-*-cperl-*-
+use strict; #-*-cperl,hi-lock,auto-fill-*-
 use warnings;
 
 use lib qw( ../../../../lib );
@@ -25,7 +25,10 @@ Algorithm::Evolutionary::Individual::Base - Base class for chromosomes that know
 
 =head1 DESCRIPTION
 
-Base class for individuals, that is, "chromosomes" in evolutionary computation algorithms. However, chromosomes needn't be bitstrings, so the name is a bit misleading. This is, however, an "empty" base class, that acts as a boilerplate for deriving others. 
+Base class for individuals, that is, "chromosomes" in evolutionary
+computation algorithms. However, chromosomes needn't be bitstrings, so
+the name is a bit misleading. This is, however, an "empty" base class,
+that acts as a boilerplate for deriving others. 
 
 =cut
 
@@ -35,12 +38,29 @@ use Algorithm::Evolutionary::Utils qw(parse_xml);
 use YAML qw(Dump Load LoadFile);
 use Carp;
 
-our ($VERSION) = ( '$Revision: 2.4 $ ' =~ / (\d+\.\d+)/ );
+our $VERSION =   sprintf "%d.%03d", q$Revision: 3.2 $ =~ /(\d+)\.(\d+)/g;
 
 use constant MY_OPERATORS => qw(None);
 
 =head1 METHODS 
 
+
+=head2 AUTOLOAD
+
+Creates methods for instance variables automatically
+
+=cut
+
+sub AUTOLOAD {
+    my $self = shift;
+    my $attr = our $AUTOLOAD;
+    $attr =~ s/.*:://;
+    return unless $attr =~ /[^A-Z]/;  # skip DESTROY and all-cap methods
+    my $instance_variable = "_$attr";
+    $self->{$instance_variable} = shift if @_;
+    return $self->{$instance_variable};
+}
+
 =head2 new( $options )
 
 Creates a new Base individual of the required class, with a fitness, and sets fitnes to undef.
@@ -71,7 +91,7 @@ sub new {
 
 =head2 create( $ref_to_hash )
 
-Creates a new random string, but uses a different interface: takes a
+Creates a new individual, but uses a different interface: takes a
 ref-to-hash, with named parameters, which gives it a common interface
 to all the hierarchy. The main difference with respect to new is that
 after creation, it is initialized with random values.
@@ -172,7 +192,8 @@ sub fromParam {
       $params{ $_->{'-name'} } = $_->{'-value'};
     }
   }
-  $thisClass = "Algorithm::Evolutionary::Individual::$thisClass" if $thisClass !~ /Algorithm::Evolutionary/;
+  $thisClass = "Algorithm::Evolutionary::Individual::$thisClass" 
+    if $thisClass !~ /Algorithm::Evolutionary/;
 
   eval "require $thisClass" || croak "Can't find $class\.pm Module";
   my $self = $thisClass->new();
@@ -340,10 +361,10 @@ L<Algorithm::Evolutionary::Individual::Bit_Vector>
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2009/02/07 18:31:28 $ 
-  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Individual/Base.pm,v 2.4 2009/02/07 18:31:28 jmerelo Exp $ 
+  CVS Info: $Date: 2009/11/17 19:19:41 $ 
+  $Header: /media/Backup/Repos/opeal/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Individual/Base.pm,v 3.2 2009/11/17 19:19:41 jmerelo Exp $ 
   $Author: jmerelo $ 
-  $Revision: 2.4 $
+  $Revision: 3.2 $
   $Name $
 
 =cut
