@@ -4,8 +4,7 @@ use warnings;
 =head1 NAME
 
 Algorithm::Evolutionary::Op::Crossover - n-point crossover
-    operator; puts a part of the second operand into the first
-    operand; can be 1 or 2 points.
+    operator; puts fragments of the second operand into the first operand
              
 
 =head1 SYNOPSIS
@@ -21,12 +20,10 @@ Algorithm::Evolutionary::Op::Crossover - n-point crossover
 
   #Apply to 2 Individuals of the String class
   my $indi = new Algorithm::Evolutionary::Individual::BitString 10;
-  my $indi2 = $indi->clone();
-  my $indi3 = $indi->clone();
   my $offspring = $op3->apply( $indi2, $indi3 ); #$indi2 == $offspring
 
   #Initialize using OO interface
-  my $op4 = new Algorithm::Evolutionary::Op::Crossover 3; #Crossover with 3 crossover points
+  my $op4 = new Algorithm::Evolutionary::Op::Crossover 2; #Crossover with 2 crossover points
 
 =head1 Base Class
 
@@ -41,7 +38,6 @@ their descendants
 for L<Algorithm::Evolutionary::Individual::Vector|Individual::Vector>
 would be  L<Algorithm::Evolutionary::Op::VectorCrossover|Op::VectorCrossover>
 
-
 =head1 METHODS
 
 =cut
@@ -50,9 +46,9 @@ package Algorithm::Evolutionary::Op::Crossover;
 
 use lib qw(../../..);
 
-our ($VERSION) = ( '$Revision: 2.1 $ ' =~ /(\d+\.\d+)/ );
+our $VERSION =   sprintf "%d.%03d", q$Revision: 3.2 $ =~ /(\d+)\.(\d+)/g; # Hack for avoiding version mismatch
 
-use Clone::Fast qw(clone);
+use Clone qw(clone);
 use Carp;
 
 use base 'Algorithm::Evolutionary::Op::Base';
@@ -60,6 +56,7 @@ use base 'Algorithm::Evolutionary::Op::Base';
 #Class-wide constants
 our $APPLIESTO =  'Algorithm::Evolutionary::Individual::String';
 our $ARITY = 2;
+our %parameters = ( numPoints => 2 );
 
 =head2 new( [$options_hash] [, $operation_priority] )
 
@@ -78,21 +75,6 @@ sub new {
   return $self;
 }
 
-=head2 create( [$num_points] )
-
-Creates a new 1 or 2 point crossover operator. But this is just to have a non-empty chromosome
-Defaults to 2 point
-
-=cut
-
-sub create {
-  my $class = shift;
-  my $self;
-  $self->{_numPoints} = shift || 2;
-  bless $self, $class;
-  return $self;
-}
-
 =head2 apply( $chromsosome_1, $chromosome_2 )
 
 Applies xover operator to a "Chromosome", a string, really. Can be
@@ -101,18 +83,15 @@ it checks before application that both operands are of type
 L<BitString|Algorithm::Evolutionary::Individual::String>.
 
 Changes the first parent, and returns it. If you want to change both
-parents at the same time, check L<QuadXOver|Algorithm::Evolutionary::Op:QuadXOver>
+parents at the same time, check L<QuadXOver|Algorithm::Evolutionary::Op::QuadXOver>
 
 =cut
 
 sub  apply ($$$){
   my $self = shift;
   my $arg = shift || croak "No victim here!";
-#  my $victim = $arg->clone();
   my $victim = clone( $arg );
   my $victim2 = shift || croak "No victim here!";
-#  croak "Incorrect type ".(ref $victim) if !$self->check($victim);
-#  croak "Incorrect type ".(ref $victim2) if !$self->check($victim2);
   my $minlen = (  length( $victim->{_str} ) >  length( $victim2->{_str} ) )?
 	 length( $victim2->{_str} ): length( $victim->{_str} );
   my $pt1 = int( rand( $minlen ) );
@@ -128,15 +107,29 @@ sub  apply ($$$){
   return $victim; 
 }
 
+=head1 SEE ALSO
+
+=over 4
+
+=item L<Algorithm::Evolutionary::Op::QuadXOver> for pass-by-reference xover
+
+=item L<Algorithm::Evolutionary::Op::Uniform_Crossover> another more mutation-like xover
+
+=item L<Algorithm::Evolutionary::Op::Gene_Boundary_Crossover> don't disturb the building blocks!
+
+=item L<Algorithm::Evolutionary::Op::Uniform_Crossover_Diff> vive la difference!
+
+=back
+
 =head1 Copyright
   
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2009/02/04 20:43:14 $ 
-  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/Crossover.pm,v 2.1 2009/02/04 20:43:14 jmerelo Exp $ 
+  CVS Info: $Date: 2011/02/14 06:55:36 $ 
+  $Header: /media/Backup/Repos/opeal/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/Crossover.pm,v 3.2 2011/02/14 06:55:36 jmerelo Exp $ 
   $Author: jmerelo $ 
-  $Revision: 2.1 $
+  $Revision: 3.2 $
   $Name $
 
 =cut
