@@ -50,10 +50,9 @@ iteration of the algorithm to the population it takes as input
 
 package Algorithm::Evolutionary::Op::Easy;
 
-our ($VERSION) = ( '$Revision: 2.2 $ ' =~ / (\d+\.\d+)/ ) ;
+our ($VERSION) = ( '$Revision: 3.5 $ ' =~ / (\d+\.\d+)/ ) ;
 
 use Carp;
-use Clone::Fast qw(clone);
 
 use Algorithm::Evolutionary::Wheel;
 use Algorithm::Evolutionary::Op::Bitflip;
@@ -148,7 +147,7 @@ sub apply ($) {
 
   #Cull
   my $pringaos = int(($#popsort+1)*$self->{_selrate}); #+1 gives you size
-  splice @popsort, $#popsort - $pringaos, $pringaos;
+  splice @popsort, -$pringaos;
  
   #Reproduce
   my @rates = map( $_->{'rate'}, @ops );
@@ -159,20 +158,23 @@ sub apply ($) {
   for ( my $i = 0; $i < $pringaos; $i ++ ) {
       my @offspring;
       my $selectedOp = $ops[ $opWheel->spin()];
+      croak "Problems with selected operator" if !$selectedOp;
       for ( my $j = 0; $j < $selectedOp->arity(); $j ++ ) {
-	  my $chosen = $popsort[ int ( rand( $originalSize ) )];
-	  push( @offspring, $chosen ); #No need to clone, it's not changed in ops
+	my $chosen = $popsort[ int ( rand( $originalSize ) )];
+	push( @offspring, $chosen ); #No need to clone, it's not changed in ops
       }
+#     p rint "Op ", ref $selectedOp, "\n";
+#      if ( (ref $selectedOp ) =~ /ssover/ ) {
+#	print map( $_->{'_str'}."\n", @offspring );
+#      }
       my $mutante = $selectedOp->apply( @offspring );
+      croak "Error aplying operator" if !$mutante;
+ #     print "Mutante ", $mutante->{'_str'}, "\n";
       push( @popsort, $mutante );
   }
 
   #Return
-  for ( my $i = 0; $i <= $#popsort; $i++ ) {
-#	print $i, "->", $popsort[$i]->asString, "\n";
-      $pop->[$i] = $popsort[$i];
-  }
-
+  @$pop = @popsort;
   
 }
 
@@ -184,13 +186,13 @@ L<Algorithm::Evolutionary::Op::FullAlgorithm>.
 
 =head1 Copyright
   
-  This file is released under the GPL. See the LICENSE file included in this distribution,
-  or go to http://www.fsf.org/licenses/gpl.txt
+This file is released under the GPL. See the LICENSE file included in this distribution,
+or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2009/02/06 16:03:04 $ 
-  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/Easy.pm,v 2.2 2009/02/06 16:03:04 jmerelo Exp $ 
+  CVS Info: $Date: 2012/11/10 10:21:08 $ 
+  $Header: /media/Backup/Repos/opeal/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/Easy.pm,v 3.5 2012/11/10 10:21:08 jmerelo Exp $ 
   $Author: jmerelo $ 
-  $Revision: 2.2 $
+  $Revision: 3.5 $
   $Name $
 
 =cut
